@@ -210,6 +210,7 @@ class AquaSource(NvdSource):
                 vendor=vendor,
                 product=pkg_name,
                 version="*",
+                edition="*",
                 version_start_including=version_start_including,
                 version_end_including=version_end_including,
                 version_start_excluding=version_start_excluding,
@@ -283,6 +284,7 @@ class AquaSource(NvdSource):
                     vendor=vendor,
                     product=pkg_name,
                     version="*",
+                    edition="*",
                     version_start_including=version_start_including,
                     version_end_including=version_end_including,
                     version_start_excluding=version_start_excluding,
@@ -368,7 +370,7 @@ class AquaSource(NvdSource):
                     status_obj.get("Status") in ("deferred", "needed")
                     and " " not in fix_note
                 ):
-                    version_end_including = "99.99.9"
+                    version_end_including = config.placeholder_fix_version
                 if pkg_name and (fix_version_start_including or version_end_including):
                     for full_pkg_name in (f"{distro_name}/{pkg_name}", pkg_name):
                         tdata = config.CVE_TPL % dict(
@@ -381,6 +383,7 @@ class AquaSource(NvdSource):
                             vendor=vendor,
                             product=full_pkg_name,
                             version="*",
+                            edition=distro_name,
                             version_start_including=version_start_including,
                             version_end_including=version_end_including,
                             version_start_excluding=version_start_excluding,
@@ -471,6 +474,7 @@ class AquaSource(NvdSource):
                     vendor="redhat",
                     product=pkg_name,
                     version="*",
+                    edition="*",
                     version_start_including=version_start_including,
                     version_end_including=version_end_including,
                     version_start_excluding=version_start_excluding,
@@ -532,6 +536,7 @@ class AquaSource(NvdSource):
                     vendor="arch",
                     product=pkg_name,
                     version="*",
+                    edition="*",
                     version_start_including=version_start_including,
                     version_end_including=version_end_including,
                     version_start_excluding=version_start_excluding,
@@ -614,6 +619,7 @@ class AquaSource(NvdSource):
                             vendor="suse",
                             product=pkg_name,
                             version="*",
+                            edition="*",
                             version_start_including=version_start_including,
                             version_end_including=version_end_including,
                             version_start_excluding=version_start_excluding,
@@ -675,6 +681,7 @@ class AquaSource(NvdSource):
                 vendor="photon",
                 product=pkg_name,
                 version="*",
+                edition="*",
                 version_start_including=version_start_including,
                 version_end_including=version_end_including,
                 version_start_excluding=version_start_excluding,
@@ -710,6 +717,12 @@ class AquaSource(NvdSource):
         description = header.get("Description", "").replace("(", "").replace(")", "")
         assigner = "debian"
         vendor = "debian"
+        filtered_annotations = [
+            ann
+            for ann in annotations
+            if ann.get("Release")
+            and (ann.get("Version") or ann.get("Kind") == "not-affected")
+        ]
         for ann in annotations:
             if ann.get("Type") == "RESERVED" or ann.get("Original") == "RESERVED":
                 continue
@@ -731,15 +744,28 @@ class AquaSource(NvdSource):
                         cve_id = bug
                         break
             kind = ann.get("Kind")
-            if kind not in ("fixed", "unfixed", "no-dsa"):
+            if kind not in (
+                "fixed",
+                "unfixed",
+                "no-dsa",
+                "end-of-life",
+                "ignored",
+                "not-affected",
+            ):
                 continue
             pkg_name = ann.get("Package")
             if not pkg_name:
                 continue
             distro_name = ann.get("Release")
+            # To reduce false positives do not store vulnerabilities without distro in certain cases
+            if not distro_name and len(filtered_annotations) > 2:
+                continue
             if distro_name:
                 pkg_name = f"{distro_name}/{pkg_name}"
-            version = ann.get("Version", "99.99.9")
+            version = ann.get("Version", config.placeholder_fix_version)
+            # We need to track not-affected entries with a special exclude version
+            if kind == "not-affected":
+                version = config.placeholder_exclude_version
             # Remove epoch
             if ":" in version:
                 version = version.split(":")[-1]
@@ -770,6 +796,7 @@ class AquaSource(NvdSource):
                     vendor=vendor,
                     product=pkg_name,
                     version="*",
+                    edition=distro_name if distro_name else "*",
                     version_start_including=version_start_including,
                     version_end_including=version_end_including,
                     version_start_excluding=version_start_excluding,
