@@ -200,7 +200,10 @@ class OSVSource(NvdSource):
             if ":" in vendor and ("alpine" in vendor or "debian" in vendor):
                 tmpV = vendor.split(":")
                 vendor = tmpV[0].lower()
-                edition = f"{vendor}-{tmpV[1]}"
+                vdistro = tmpV[1]
+                if vendor == "alpine":
+                    vdistro = vdistro.replace("v", "")
+                edition = f"{vendor}-{vdistro}"
                 # Only use the precise version for debian
                 if "debian" in vendor:
                     pkg_name_list = [f"{edition}/{pkg_name}"]
