@@ -8,6 +8,8 @@ from cvss import CVSS3
 from packageurl import PackageURL
 from semver import VersionInfo
 
+from collections import Counter
+
 from vdb.lib import CPE_FULL_REGEX, PackageIssue, Severity, VulnerabilityOccurrence
 
 date_format_str = "%Y-%m-%dT%H:%M:%S"
@@ -463,6 +465,13 @@ def version_compare(
     )
     ubuntu_mode_detected = False
     if epoch_mode_detected:
+        # Easy check
+        if (
+            compare_ver
+            and max_affected_version_excluding
+            and compare_ver == max_affected_version_excluding
+        ):
+            return False
         (
             tcompare_ver,
             tmin_version,
@@ -499,44 +508,101 @@ def version_compare(
             ):
                 return True
         # Sorry about this but ubuntu versioning scheme is a PITA
-        if "ubuntu" in compare_ver or "build" in compare_ver:
+        if "ubuntu" in compare_ver or "build" in compare_ver or "deb" in compare_ver:
             compare_with_build_tag = False
             # Trim any epoch
             if ":" in compare_ver:
                 compare_ver = compare_ver.split(":")[-1]
+            if max_version and ":" in max_version:
+                max_version = max_version.split(":")[-1]
+            if max_affected_version_excluding and ":" in max_affected_version_excluding:
+                max_affected_version_excluding = max_affected_version_excluding.split(
+                    ":"
+                )[-1]
             if "ubuntu" in compare_ver:
                 tmpcvArr = compare_ver.split("ubuntu")
+            elif "deb" in compare_ver:
+                tmpcvArr = compare_ver.split("deb")
             else:
                 tmpcvArr = compare_ver.split("build")
                 compare_with_build_tag = True
             ubuntu_mode_detected = True
-            if max_version and ("ubuntu" in max_version or "-" in max_version):
+            tmpmv = None
+            if max_version and (
+                "ubuntu" in max_version or "-" in max_version or "deb" in max_version
+            ):
+                indexToUse = 0
                 if max_version.startswith(tmpcvArr[0]):
-                    tmpmv = max_version.split("ubuntu")[-1]
-                    compare_ver = tmpcvArr[-1]
-                else:
-                    tmpmv = max_version.split("ubuntu")[0]
-                    compare_ver = tmpcvArr[0]
-                max_version = tmpmv
-                if "-" in max_version:
+                    indexToUse = -1
+                if "ubuntu" in max_version:
+                    tmpmv = max_version.split("ubuntu")[indexToUse]
+                elif "deb" in max_version:
+                    tmpmv = max_version.split("deb")[indexToUse]
+                compare_ver = tmpcvArr[indexToUse]
+                if tmpmv:
+                    max_version = tmpmv
+                if max_version and "-" in max_version:
                     max_version = max_version.split("-")[0]
             elif max_affected_version_excluding and (
                 "ubuntu" in max_affected_version_excluding
+                or "deb" in max_affected_version_excluding
                 or "-" in max_affected_version_excluding
             ):
+                indexToUse = 0
                 if max_affected_version_excluding.startswith(tmpcvArr[0]):
-                    tmpmv = max_affected_version_excluding.split("ubuntu")[-1]
-                    compare_ver = tmpcvArr[-1]
-                else:
-                    tmpmv = max_affected_version_excluding.split("ubuntu")[0]
-                    compare_ver = tmpcvArr[0]
+                    indexToUse = -1
+                for bstr in ("ubuntu", "deb", "-"):
+                    if bstr in max_affected_version_excluding:
+                        tmpmvArr = max_affected_version_excluding.split(bstr)
+                        # If the prefix is equal after splitting operate with suffix alone
+                        if tmpmvArr[0] == tmpcvArr[0]:
+                            indexToUse = -1
+                        tmpmv = tmpmvArr[indexToUse]
+                        break
+                compare_ver = tmpcvArr[indexToUse]
                 max_affected_version_excluding = tmpmv
-                if "-" in max_affected_version_excluding:
+                if (
+                    max_affected_version_excluding
+                    and "-" in max_affected_version_excluding
+                ):
                     max_affected_version_excluding = (
                         max_affected_version_excluding.split("-")[0]
                     )
             if "-" in compare_ver:
                 compare_ver = compare_ver.split("-")[0]
+            # If after splitting the versions are equal return False
+            if (max_version and compare_ver == max_version) or (
+                max_affected_version_excluding
+                and compare_ver == max_affected_version_excluding
+            ):
+                return False
+            if max_affected_version_excluding:
+                if VersionInfo.isvalid(compare_ver) and VersionInfo.isvalid(
+                    max_affected_version_excluding
+                ):
+                    cmp_value = VersionInfo.parse(compare_ver).compare(
+                        max_affected_version_excluding
+                    )
+                    return cmp_value < 0
+                elif (
+                    "." not in compare_ver and "." not in max_affected_version_excluding
+                ):
+                    compare_ver = re.split(r"[+~]", compare_ver)[0]
+                    max_affected_version_excluding = re.split(
+                        r"[+~]", max_affected_version_excluding
+                    )[0]
+                    exnum = list(filter(str.isdigit, compare_ver))
+                    if exnum:
+                        compare_ver_restnum = int("".join(exnum))
+                        exnum = list(
+                            filter(str.isdigit, max_affected_version_excluding)
+                        )
+                        if exnum:
+                            max_affected_version_excluding_restnum = int("".join(exnum))
+                            return (
+                                compare_ver_restnum
+                                < max_affected_version_excluding_restnum
+                            )
         if not ubuntu_mode_detected:
             compare_ver = tcompare_ver
             min_version = tmin_version
@@ -592,10 +658,17 @@ def version_compare(
             min_value = compare_semver.compare(min_semver)
             max_value = compare_semver.compare(max_semver)
             # If we are confident about the versions post upgrade then return True
-            min_check = min_value > 0 if is_min_exclude else min_value >= 0
-            max_check = max_value < 0 if is_max_exclude else max_value <= 0
+            min_check = (
+                min_value > 0
+                if is_min_exclude and not ubuntu_mode_detected
+                else min_value >= 0
+            )
+            max_check = (
+                max_value < 0
+                if is_max_exclude and not ubuntu_mode_detected
+                else max_value <= 0
+            )
             return min_check and max_check
-
     compare_ver_build = None
     min_version_build = None
     max_version_build = None
